@@ -1,31 +1,42 @@
 __title__ = 'aiohttp-socks'
-__version__ = '0.4.2'
+__version__ = '0.8.0'
+
+from python_socks import (
+    ProxyError,
+    ProxyTimeoutError,
+    ProxyConnectionError,
+    ProxyType
+)
 
-from .proxy import SocksVer, ProxyType
 from .connector import (
-    SocksConnector, ProxyConnector,
-    ChainProxyConnector, ProxyInfo
+    ProxyConnector,
+    ChainProxyConnector,
+    ProxyInfo
 )
 from .utils import open_connection, create_connection
-from .proxy.errors import (
-    ProxyError, ProxyConnectionError, ProxyTimeoutError,
-    SocksError, SocksConnectionError,
+
+from ._deprecated import (
+    SocksVer,
+    SocksConnector,
+    SocksConnectionError,
+    SocksError
 )
 
 __all__ = (
     '__title__',
     '__version__',
-    'SocksConnector',
     'ProxyConnector',
     'ChainProxyConnector',
     'ProxyInfo',
-    'SocksVer',
     'ProxyType',
     'ProxyError',
     'ProxyConnectionError',
     'ProxyTimeoutError',
+    'open_connection',
+    'create_connection',
+
+    'SocksVer',
+    'SocksConnector',
     'SocksError',
     'SocksConnectionError',
-    'open_connection',
-    'create_connection'
 )
